==> haskell-hls-explicit-fixity-plugin-1.1.0.0-160-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-fixity-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-1.1.0.0-1jePQ69LWeVI0h63BY7Kw6
key:                  hls-explicit-fixity-plugin-1.1.0.0-1jePQ69LWeVI0h63BY7Kw6
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  8df181c8d46c53525f1048ebc696198e
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-fixity-plugin-1.1.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-fixity-plugin-1.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-1.1.0.0-1jePQ69LWeVI0h63BY7Kw6
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    extra-1.7.14-JZwVFNOTzAl9wNXhTRS6o8 ghc-9.2.8
    ghcide-1.9.1.0-HwAkVTDd37EFvNbRQNs88T
    hashable-1.4.3.0-7566tBsT9J8EFScR3Tb2Bc
    hls-plugin-api-1.6.0.0-6Ebop0G4HfEC83Y5bnhsUu
    lsp-1.6.0.0-1JAbQDnc0SK1hycTz4LLrJ text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-1.1.0.0-204-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-explicit-fixity-plugin
version:              1.1.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-1.1.0.0-IwiPS5CgwoxLHiqc4UJq4s
key:                  hls-explicit-fixity-plugin-1.1.0.0-IwiPS5CgwoxLHiqc4UJq4s
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  22e074ed8de8b3f67dcf3eaaa6f39335
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-fixity-plugin-1.1.0.0

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/hls-explicit-fixity-plugin-1.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-1.1.0.0-IwiPS5CgwoxLHiqc4UJq4s
depends:
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    extra-1.7.15-9PmwGQvWkElDwGNWrixqMB ghc-9.2.8
    ghcide-1.10.0.0-42asgJmBwLYDXfQ3kee4Wu
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    hls-plugin-api-1.6.0.0-GBhVrEAXY9G7a8rlmXAPNi
    lsp-1.6.0.0-3mgfXrOs4nYBY8raCTSUiO text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
